.. _using_galaxy:
.. _ansible_galaxy:

**********
User Guide
**********

:dfn:`Ansible Galaxy` refers to the `Galaxy <https://galaxy.ansible.com>`_  website, a free site for finding, downloading, and sharing community developed roles.

Use Galaxy to jump-start your automation project with great content from the Ansible community. Galaxy provides pre-packaged units of work such as `roles <playbooks_reuse_roles>`_, and new in Galaxy 3.2, `collections <collections>`_.
You can find roles for provisioning infrastructure, deploying applications, and all of the tasks you do everyday. The collection format provides a comprehensive package of automation that may include multiple playbooks, roles, modules, and plugins.

.. toctree::
   :maxdepth: 2

   finding_collections
   finding_roles
   installing_collections
   installing_roles


.. seealso::
  `collections <collections>`_
    Sharable collections of modules, playbooks and roles
  `roles <playbooks_reuse_roles>`_
    Reusable tasks, handlers, and other files in a known directory structure
